import { webIconStyles } from "./iconStyles/iconStyles.web";
import { mobileIconStyles } from "./iconStyles/iconStyles.mobile";
import { iconSizes } from "./iconStyles/iconSizes";
import { iconColors } from "./iconStyles/iconColors";
import iconMap from "./assets/icon.map";
import webTokens from "./assets/tokens.web";
import androidTokens from "./assets/tokens.android";
import iosTokens from "./assets/tokens.ios";
import colors from "./assets/tokens.color";
import allColors from "./assets/tokens.all.colors";
import semantic from "./assets/tokens.semantic";
import darkTokens from "./assets/tokens.dark";
type WebTokens = typeof webTokens;
type MobileTokens = typeof androidTokens;
export { webTokens as tokens, webTokens, allColors, androidTokens, darkTokens, iosTokens, iconMap, webIconStyles, mobileIconStyles, iconSizes, iconColors, type WebTokens, type MobileTokens, colors, semantic, };
interface IconProps {
    /** The icon to show.  */
    readonly name: keyof typeof iconMap.icons | ExtraIconNames;
    /**
     * Changes the size to small or large.
     * @default base
     */
    readonly size?: keyof typeof iconSizes.tokens;
    /**
     * Determines the color of the icon. Some icons have a default system color
     * like quotes, jobs, and invoices. Others that doesn't have a system color
     * falls back to greyBlueDark.
     */
    readonly color?: keyof typeof iconColors.tokens;
}
interface GetIconProps extends IconProps {
    platform: "web" | "mobile";
    format?: "css" | "js";
}
export declare function getIcon({ name, color, platform, size, format, }: GetIconProps): {
    readonly svgStyle: {
        fill?: string | undefined;
        width: string | number;
        height: string | number;
    };
    readonly pathStyle: {
        fill: string;
    };
    readonly paths: string[];
    readonly viewBox: string;
};
export type ExtraIconNames = "longArrowUp" | "longArrowDown" | "longArrowRight" | "longArrowLeft" | "remove" | "thumbsDown" | "truck";
export type IconNames = keyof typeof iconMap.icons | ExtraIconNames;
export type IconSizes = keyof typeof iconSizes.tokens;
export type IconColorNames = keyof typeof iconColors.tokens;
